==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/java/memory/memory-core/src/main/java/org/apache/arrow/memory/ForeignAllocation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.arrow.memory;

/**
 * EXPERIMENTAL: a memory allocation that does not come from a BufferAllocator, but rather an outside source (like JNI).
 *
 * <p>To use this, subclass this class and implement {@link #release0()} to free the allocation.
 */
public abstract class ForeignAllocation {
  private final long memoryAddress;
  private final long size;

  /**
   * Create a new AllocationManager representing an imported buffer.
   *
   * @param size The buffer size.
   * @param memoryAddress The buffer address.
   */
  protected ForeignAllocation(long size, long memoryAddress) {
    this.memoryAddress = memoryAddress;
    this.size = size;
  }

  /**
   * Get the size of this allocation.
   */
  public long getSize() {
    return size;
  }

  /**
   * Get the address of this allocation.
   */
  protected long memoryAddress() {
    return memoryAddress;
  }

  /**
   * Free this allocation. Will only be called once.
   */
  protected abstract void release0();
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/java/memory/memory-core/src/main/java/org/apache/arrow/memory/ForeignAllocation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.arrow.memory;

/**
 * EXPERIMENTAL: a memory allocation that does not come from a BufferAllocator, but rather an
 * outside source (like JNI).
 *
 * <p>To use this, subclass this class and implement {@link #release0()} to free the allocation.
 */
public abstract class ForeignAllocation {
  private final long memoryAddress;
  private final long size;

  /**
   * Create a new AllocationManager representing an imported buffer.
   *
   * @param size The buffer size.
   * @param memoryAddress The buffer address.
   */
  protected ForeignAllocation(long size, long memoryAddress) {
    this.memoryAddress = memoryAddress;
    this.size = size;
  }

  /** Get the size of this allocation. */
  public long getSize() {
    return size;
  }

  /** Get the address of this allocation. */
  protected long memoryAddress() {
    return memoryAddress;
  }

  /** Free this allocation. Will only be called once. */
  protected abstract void release0();
}
